<bookshelf>
  <div class="year-list">
    <span
      each={ year in years }
      class={"year": true, "selected": year === selectedYear }
      onclick={ selectYear }>
      { year }
    </span>
  </div>
  <div class="container book">
    <div class="grid-item" each={ book in booksByYear }>
      <div>
        <img src="/static/assets/books/covers/{ book.cover }">
      </div>
      <div>
        <div class="title">{ book.title }</div>
        <div class="author">{ book.author }</div>
        <span if={ book.readMore }><a href="https://marginalia.cloud/{ book.readMore }">Read more</a> →</span>
      </div>
      <div class="rating">
        <div class="stars" title="Rating">
          <i each={ book.rating } class="icon icon-star"></i>
        </div>
        <div class="meta-icons">
          <div class="heart" title="Favourite" if={ book.favourite }>
            <i class="icon icon-heart"></i>
          </div>
          <div class="audio" title="Audiobook" if={ book.audiobook }>
            <i class="icon icon-headphones"></i>
          </div>
          <div class="reread" title="Reread" if={ book.reread }>
            <i class="icon icon-cw"></i>
          </div>
        </div>
      </div>
    </div>
  </div>

  <script>
    const self = this;
    self.books = [];
    self.booksByYear = [];
    self.years = [];
    self.selectedYear = null;

    self.on('mount', function() {
      getBooks();
    });

    slugify(author, title) {
      return `${author}-${title}`.replace(/\s/g , "-").toLowerCase();
    }

    selectYear(e) {
      self.selectedYear = e.item.year;
      filterBooksByYear();
      self.update();
    }

    const getBooks = function() {
      const apiUrl = `/api/list/books`;
      fetch(apiUrl, {method: 'GET', mode: 'cors'}).then(response => {
        response.json().then(data => {
          self.books = transformStars(data);
          self.years = [...new Set(self.books.map(book => book.dateRead.substring(0,4)))];
          self.selectedYear = self.years[0];
          filterBooksByYear();

          self.update();
        });
      }).catch(error => {
        console.log('error', error);
      });
    };

    const transformStars = function(books) {
      return books.map(function(book) {
        const transformedBook = { ...book };
        transformedBook.rating = Array(book.rating).fill();
        return transformedBook;
      });
    }

    const filterBooksByYear = function(books) {
      self.booksByYear = self.books.filter(book => book.dateRead.substring(0,4) === self.selectedYear);
      self.update();
    }
  </script>
</bookshelf>
